summaryrefslogtreecommitdiff
path: root/src/arch/dalvik/operands/register.c
diff options
context:
space:
mode:
authorCyrille Bagard <nocbos@gmail.com>2016-01-30 00:21:08 (GMT)
committerCyrille Bagard <nocbos@gmail.com>2016-01-30 00:21:08 (GMT)
commitc922b6b9c841a97dd948755658cff07b2c6762ff (patch)
tree7236b03fde56edde625e406085862381cde6e955 /src/arch/dalvik/operands/register.c
parent16e0fd9d89ef433848678dfc8dd20426844a2868 (diff)
Updated some parts of the code dealing with Dalvik.
Diffstat (limited to 'src/arch/dalvik/operands/register.c')
-rw-r--r--src/arch/dalvik/operands/register.c19
1 files changed, 9 insertions, 10 deletions
diff --git a/src/arch/dalvik/operands/register.c b/src/arch/dalvik/operands/register.c
index 1b789f2..7f243ad 100644
--- a/src/arch/dalvik/operands/register.c
+++ b/src/arch/dalvik/operands/register.c
@@ -159,12 +159,11 @@ static void g_dalvik_register_operand_finalize(GDalvikRegisterOperand *operand)
/******************************************************************************
* *
* Paramètres : data = flux de données à analyser. *
* pos = position courante dans ce flux. [OUT] *
* end = limite des données à analyser. *
* low = position éventuelle des 4 bits visés. [OUT] *
* size = taille de l'opérande, et donc du registre. *
* endian = ordre des bits dans la source. *
* *
* Description : Crée un opérande visant un registre Dalvik. *
* *
@@ -174,7 +173,7 @@ static void g_dalvik_register_operand_finalize(GDalvikRegisterOperand *operand)
* *
******************************************************************************/
-GArchOperand *g_dalvik_register_operand_new(const bin_t *data, off_t *pos, off_t end, bool *low, MemoryDataSize size, SourceEndian endian)
+GArchOperand *g_dalvik_register_operand_new(const GBinContent *content, vmpa2t *pos, bool *low, MemoryDataSize size, SourceEndian endian)
{
GDalvikRegisterOperand *result; /* Structure à retourner */
uint8_t index8; /* Indice sur 8 bits */
@@ -184,13 +183,13 @@ GArchOperand *g_dalvik_register_operand_new(const bin_t *data, off_t *pos, off_t
switch (size)
{
case MDS_4_BITS:
- test = read_u4(&index8, data, pos, end, low);
+ test = g_binary_content_read_u4(content, pos, low, &index8);
break;
case MDS_8_BITS:
- test = read_u8(&index8, data, pos, end);
+ test = g_binary_content_read_u8(content, pos, &index8);
break;
case MDS_16_BITS:
- test = read_u16(&index16, data, pos, end, endian);
+ test = g_binary_content_read_u16(content, pos, endian, &index16);
break;
default:
test = false;
@@ -159,12 +159,11 @@ static void g_dalvik_register_operand_finalize(GDalvikRegisterOperand *operand)
/******************************************************************************
* *
-* Paramètres : data = flux de données à analyser. *
-* pos = position courante dans ce flux. [OUT] *
-* end = limite des données à analyser. *
-* low = position éventuelle des 4 bits visés. [OUT] *
-* size = taille de l'opérande, et donc du registre. *
-* endian = ordre des bits dans la source. *
+* Paramètres : content = flux de données à analyser. *
+* pos = position courante dans ce flux. [OUT] *
+* low = position éventuelle des 4 bits visés. [OUT] *
+* size = taille de l'opérande, et donc du registre. *
+* endian = ordre des bits dans la source. *
* *
* Description : Crée un opérande visant un registre Dalvik. *